@@ -12,14 +12,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from selenium import webdriver
+from typing import Any, Dict, Union
+
+from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 
 from ..mobilecommand import MobileCommand as Command
 
 
-class ImagesComparison(webdriver.Remote):
-
-    def match_images_features(self, base64_image1, base64_image2, **opts):
+class ImagesComparison(CanExecuteCommands):
+    def match_images_features(self, base64_image1: bytes, base64_image2: bytes, **opts: Any) -> Dict[str, Any]:
         """Performs images matching by features.
 
         Read
@@ -28,8 +29,8 @@ class ImagesComparison(webdriver.Remote):
         The method supports all image formats, which are supported by OpenCV itself.
 
         Args:
-            base64_image1 (bytes): base64-encoded content of the first image
-            base64_image2 (bytes): base64-encoded content of the second image
+            base64_image1: base64-encoded content of the first image
+            base64_image2: base64-encoded content of the second image
 
         Keyword Args:
             visualize (bool): Set it to True in order to return the visualization of the matching operation.
@@ -56,7 +57,7 @@ class ImagesComparison(webdriver.Remote):
                 It is equal to `count` if `goodMatchesFactor` does not limit the matches,
                 otherwise it contains the total count of matches before `goodMatchesFactor` is
                 applied.
-            points1 (dict)): The array of matching points on the first image. Each point is a dictionary
+            points1 (dict): The array of matching points on the first image. Each point is a dictionary
                 with 'x' and 'y' keys
             rect1 (dict): The bounding rect for the `points1` array or a zero rect if not enough matching points
                 were found. The rect is represented by a dictionary with 'x', 'y', 'width' and 'height' keys
@@ -65,15 +66,12 @@ class ImagesComparison(webdriver.Remote):
             rect2 (dict): The bounding rect for the `points2` array or a zero rect if not enough matching points
                 were found. The rect is represented by a dictionary with 'x', 'y', 'width' and 'height' keys
         """
-        options = {
-            'mode': 'matchFeatures',
-            'firstImage': base64_image1,
-            'secondImage': base64_image2,
-            'options': opts
-        }
+        options = {'mode': 'matchFeatures', 'firstImage': base64_image1, 'secondImage': base64_image2, 'options': opts}
         return self.execute(Command.COMPARE_IMAGES, options)['value']
 
-    def find_image_occurrence(self, base64_full_image, base64_partial_image, **opts):
+    def find_image_occurrence(
+        self, base64_full_image: bytes, base64_partial_image: bytes, **opts: Any
+    ) -> Dict[str, Union[bytes, Dict]]:
         """Performs images matching by template to find possible occurrence of the partial image
         in the full image.
 
@@ -83,28 +81,31 @@ class ImagesComparison(webdriver.Remote):
         The method supports all image formats, which are supported by OpenCV itself.
 
         Args:
-            base64_full_image (bytes): base64-encoded content of the full image
-            base64_partial_image (bytes): base64-encoded content of the partial image
+            base64_full_image: base64-encoded content of the full image
+            base64_partial_image: base64-encoded content of the partial image
 
         Keyword Args:
             visualize (bool): Set it to True in order to return the visualization of the matching operation.
                 False by default
 
         Returns:
-            visualization (bytes): base64-encoded content of PNG visualization of the current comparison
-                operation. This entry is only present if `visualize` option is enabled
-            rect (dict): The region of the partial image occurrence on the full image.
-                The rect is represented by a dictionary with 'x', 'y', 'width' and 'height' keys
+            The dictionary containing the following entries:
+                visualization (bytes): base64-encoded content of PNG visualization of the current comparison
+                    operation. This entry is only present if `visualize` option is enabled
+                rect (dict): The region of the partial image occurrence on the full image.
+                    The rect is represented by a dictionary with 'x', 'y', 'width' and 'height' keys
         """
         options = {
             'mode': 'matchTemplate',
             'firstImage': base64_full_image,
             'secondImage': base64_partial_image,
-            'options': opts
+            'options': opts,
         }
         return self.execute(Command.COMPARE_IMAGES, options)['value']
 
-    def get_images_similarity(self, base64_image1, base64_image2, **opts):
+    def get_images_similarity(
+        self, base64_image1: bytes, base64_image2: bytes, **opts: Any
+    ) -> Dict[str, Union[bytes, Dict]]:
         """Performs images matching to calculate the similarity score between them.
 
         The flow there is similar to the one used in
@@ -112,29 +113,24 @@ class ImagesComparison(webdriver.Remote):
         The method supports all image formats, which are supported by OpenCV itself.
 
         Args:
-            base64_image1 (bytes): base64-encoded content of the first image
-            base64_image2 (bytes): base64-encoded content of the second image
+            base64_image1: base64-encoded content of the first image
+            base64_image2: base64-encoded content of the second image
 
         Keyword Args:
-            visualize (bool): Set it to True in order to return the visualization of the matching operation.
+            visualize (boo): Set it to True in order to return the visualization of the matching operation.
                 False by default
 
         Returns:
-            visualization (bytes): base64-encoded content of PNG visualization of the current comparison
-                operation. This entry is only present if `visualize` option is enabled
-            score (float): The similarity score as a float number in range [0.0, 1.0].
-                1.0 is the highest score (means both images are totally equal).
+            The dictionary containing the following entries:
+                visualization (bytes): base64-encoded content of PNG visualization of the current comparison
+                    operation. This entry is only present if `visualize` option is enabled
+                score (float): The similarity score as a float number in range [0.0, 1.0].
+                    1.0 is the highest score (means both images are totally equal).
         """
-        options = {
-            'mode': 'getSimilarity',
-            'firstImage': base64_image1,
-            'secondImage': base64_image2,
-            'options': opts
-        }
+        options = {'mode': 'getSimilarity', 'firstImage': base64_image1, 'secondImage': base64_image2, 'options': opts}
         return self.execute(Command.COMPARE_IMAGES, options)['value']
 
-    # pylint: disable=protected-access
-
-    def _addCommands(self):
-        self.command_executor._commands[Command.COMPARE_IMAGES] = \
-            ('POST', '/session/$sessionId/appium/compare_images')
+    def _add_commands(self) -> None:
+        # noinspection PyProtectedMember,PyUnresolvedReferences
+        commands = self.command_executor._commands
+        commands[Command.COMPARE_IMAGES] = ('POST', '/session/$sessionId/appium/compare_images')
